This function calculates the ages, confidence intervals and standard deviations from triplets (U,Th,Ph), obtained by electron microprobe, given together with corresponding errors.
calculateAges(measures, nloops = 1000, level = 0.05, verbose = TRUE, seed = NULL)An object of class ages.
a data.frame object with one electron microprobe measurement
by row and with columns U, corresponding error for U, Th, corresponding error
for Th, Pb, corresponding error for Pb, all expressed in ppm. See an example
with data(srilanka).
the number of Monte Carlo (MC) simulations used to estimate the
confidence intervals for the ages. Default is 1000.
the level of significance of the confidence intervals for the
ages. Default is 0.05.
logical; activates the verbose mode. Default is TRUE.
if supplied, initialize the random seed. Default is NULL
(the random seed is not initialized).
Jean-Marc Montel, jean-marc.montel@ensg.inpl-nancy.fr
Nathalie Vialaneix, nathalie.vialaneix@inrae.fr
The ages are calculated by solving the Equation (1) of Montel et al.
(1996). The equation is solved by the Broyden method implemented in the
nleqslv() function.
The standard deviations and the confidence intervals are calculated using a MC approach: randomized observations of the triplets are generated from normal distributions with standard deviations equal to \(\frac{\textrm{error}}{2}\) where 'error' denotes the error in the measurement of Th, U or Pb, passed in measures. Standard deviations are estimated by the empirical standard deviations and confidence intervals by quantiles for probabilities \(\frac{\textrm{\texttt{level}}}{2}\) and \(1-\frac{\textrm{\texttt{level}}}{2}\), respectively.
Montel J.M., Foret S., Veschambre M., Nicollet C., Provost A. (1996) Electron microprobe dating of monazite. Chemical Geology, 131, 37--53.
ages tests
## Load the data
data(srilanka)
## Calculate the ages
calculateAges(srilanka, nloops=10)
Run the code above in your browser using DataLab